==> language-env_0.38.tar.gz: language-env-0.38/ja/dot.xsession.pl <==
#xs comment -*-coding: euc-jp;-*-
xdm WO TSUKATTE X Window System NI login SHITA TOKI NI JIKKOU SAREMASU.
MATA, startx YA xinit WO TSUKATTE X WO KIDOU SHITA TOKI NIMO JIKKOU SAREMASU.
END
xdm Ȥä X Window System ˥󤷤Ȥ˼¹Ԥޤ
ޤstartx  xinit Ȥä X ưȤˤ¹Ԥޤ
END
print <<'EOF';
# ʲΥѿˤäơưѤޤ
# $TERMINAL_EMULATOR
# $WINDOW_MANAGER
LANG=ja_JP.eucJP
export LANG
PATH=$HOME/bin:$PATH
#=======================================================================
# ܸ (XIM) 
EOF


print "# XIM С̾\n";
print "# (XIM, XIM2 ϡlanguage-env ǻȤѿǤ)\n";
if ($IM_DEFAULT eq "Canna") {
	print "XIM=kinput2\n";
	print "XIM2=-canna\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "XIM=kinput2\n";
	print "XIM2=-wnn\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "XIM=skkinput\n";
	print "XIM2=\n";
} 
if ($IM_HOST{"Canna"} ne "") {
	print "CANNAHOST=$IM_HOST{'Canna'}\nexport CANNAHOST\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "JSERVER=$IM_HOST{'Wnn'}\nexport JSERVER\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "SKKSERVER=$IM_HOST{'SKK'}\nexport SKKSERVER\n";
}


print <<'EOF';
# XIM Сư
if type $XIM &> /dev/null
then
  $XIM $XIM2 &
fi
XMODIFIERS=@im=$XIM
export XMODIFIERS

#=======================================================================
# ߥʥ륨ߥ졼 (xterm, kterm, rxvt, ...) ư
# .xsession Ρlanguage-env 񤭹 $TERMINAL_EMULATOR 
# ꤹȡưѤޤ
# $TERMINAL_EMULATOR ꤵƤСư롣
# $TERMINAL_EMULATOR  NONE ʤ顢ưʤ
#      ɥޥ͡㡼鵯ưʤɤξ˻ꤷƤ
# $TERMINAL_EMULATOR ꤵƤʤСǥեȤư
#      (krxvt -> kterm -> rxvt -> Eterm -> gnome-terminal -> xterm νǸ)
#
# krxvt ϡrxvt-ml ѥåäƤܸб rxvt Ǥ
#-----------------------------------------------------------------------
if [ -z "$TERMINAL_EMULATOR" ] ; then
  if type krxvt &> /dev/null ; then
    XMODIFIERS=@im=$XIM krxvt -ls &
  elif type kterm &> /dev/null ; then
    kterm -ls &
  elif type rxvt &> /dev/null ; then
    XMODIFIERS=@im=$XIM rxvt -ls &
  elif type Eterm &> /dev/null ; then
    Eterm -l &
  elif type gnome-terminal &> /dev/null ; then
    gnome-terminal --login &
  elif type xterm &> /dev/null ; then
    xterm -ls &
  fi
elif [ "$TERMINAL_EMULATOR" != "NONE" ] ; then
  $TERMINAL_EMULATOR &
fi

#=======================================================================
# ط
# (xlogo64 ϡxlib6g-dev ѥåäƤޤ)
#xsetroot -bitmap /usr/X11R6/include/X11/bitmaps/xlogo64 -fg RoyalBlue -bg RoyalBlue4 &
#xsetroot -solid SkyBlue
# ޥηˤ
#xsetroot -cursor /usr/include/X11/bitmaps/left_ptr /usr/include/X11/bitmaps/left_ptrmsk
EOF

if ($DOTFILECONTENTS2 eq "") {
	# ʾˤϤʤˤʤ
	print <<'EOF';
#
#=======================================================================
# åޥ͡㡢ɥޥ͡㡢ߥʥ륨ߥ졼
# 줫¹Ԥޤ ɤ줫ҤȤĤɬפǤ
# ¹Ԥ륦ɥޥ͡ $WINDOW_MANAGER ǻǽǤ
if [ -x "$WINDOW_MANAGER" ]; then
  realstartup=$WINDOW_MANAGER
elif [ -x /usr/bin/x-session-manager ]; then
  realstartup=x-session-manager
elif [ -x /usr/bin/x-window-manager ]; then
  realstartup=x-window-manager
elif [ -x /usr/bin/x-terminal-emulator ]; then
  realstartup=x-terminal-emulator
fi
exec $realstartup
EOF
} else {
	print <<'EOF';

#=======================================================================
# ɥޥ͡¹Ԥ꤬硢¹Ԥޤ
# $PASS_THROUGH 硢ɥޥ͡ϥХå饦ɤ
# ưʹߤƤ¹Ԥޤʤϻꥦɥޥ͡㤬
# ȤޤǤäȼ¹Ԥ졢ʹߤƤϼ¹Ԥޤ
if type "$WINDOW_MANAGER" >& /dev/null ; then
  if [ -z "$PASS_THROUGH" ]; then
    exec $WINDOW_MANAGER
  else
    $WINDOW_MANAGER &
  fi
fi
#=======================================================================
# $WINDOW_MANAGER λ꤬ʤȤޤϡ$WINDOW_MANAGER λ꤬
# ä $PASS_THROUGH λ⤢Ȥϡ³Ƥ³
# ¹Ԥޤ⤷åޥ͡䥦ɥޥ͡ʤɤ
# ¹Ԥ륳ޥɤʤ~/.xsession ˽λƤޤ硢
# 󤷤Ƥ⤹˥ȤƤޤʤɤԶ礬ޤΤ
# դƤ
EOF
}

==> language-env_0.64.tar.gz: language-env-0.63/ja/dot.xsession.pl <==
#xs comment -*-coding: euc-jp;-*-
xdm WO TSUKATTE X Window System NI login SHITA TOKI NI JIKKOU SAREMASU.
MATA, startx YA xinit WO TSUKATTE X WO KIDOU SHITA TOKI NIMO JIKKOU SAREMASU.
END
xdm Ȥä X Window System ˥󤷤Ȥ˼¹Ԥޤ
ޤstartx  xinit Ȥä X ưȤˤ¹Ԥޤ
END
print <<'EOF';
# ʲΥѿˤäơưѤޤ
# $TERMINAL_EMULATOR
# $WINDOW_MANAGER
LANG=ja_JP.eucJP
export LANG
PATH=$HOME/bin:$PATH
#=======================================================================
# ܸ (XIM) 
EOF

print "# XIM Сư\n";
if ($IM_DEFAULT eq "Canna") {
	print "if type kinput2 &> /dev/null ; then\n";
	print "  kinput2 -canna &\n";
	print "fi\n";
	print "XMODIFIERS=\@im=kinput2 ; export XMODIFIERS\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "if type kinput2 &> /dev/null ; then\n";
	print "  kinput2 -wnn &\n";
	print "fi\n";
	print "XMODIFIERS=\@im=kinput2 ; export XMODIFIERS\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "if type skkinput &> /dev/null ; then\n";
	print "  skkinput &\n";
	print "fi\n";
	print "XMODIFIERS=\@im=skkinput ; export XMODIFIERS\n";
} elsif ($IM_DEFAULT eq "Anthy") {
	print "if type uim-xim &> /dev/null ; then\n";
	print "  uim-xim &\n";
	print "fi\n";
	print "XMODIFIERS=\@im=uim-anthy ; export XMODIFIERS\n";
} elsif ($IM_DEFAULT eq "PRIME") {
	print "if type uim-xim &> /dev/null ; then\n";
	print "  uim-xim &\n";
	print "fi\n";
	print "XMODIFIERS=\@im=uim-prime ; export XMODIFIERS\n";
} 

if ($IM_HOST{"Canna"} ne "") {
	print "CANNAHOST=$IM_HOST{'Canna'}\nexport CANNAHOST\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "JSERVER=$IM_HOST{'Wnn'}\nexport JSERVER\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "SKKSERVER=$IM_HOST{'SKK'}\nexport SKKSERVER\n";
}


print <<'EOF';
#=======================================================================
# ߥʥ륨ߥ졼 (xterm, kterm, rxvt, ...) ư
# .xsession Ρlanguage-env 񤭹 $TERMINAL_EMULATOR 
# ꤹȡưѤޤ
# $TERMINAL_EMULATOR ꤵƤСư롣
# $TERMINAL_EMULATOR  NONE ʤ顢ưʤ
#      ɥޥ͡㡼鵯ưʤɤξ˻ꤷƤ
# $TERMINAL_EMULATOR ꤵƤʤСǥեȤư
#      (krxvt -> kterm -> rxvt -> Eterm -> gnome-terminal -> xterm νǸ)
#
# krxvt ϡrxvt-ml ѥåäƤܸб rxvt Ǥ
#-----------------------------------------------------------------------
if [ -z "$TERMINAL_EMULATOR" ] ; then
  if type krxvt &> /dev/null ; then
    XMODIFIERS=@im=$XIM krxvt -ls &
  elif type kterm &> /dev/null ; then
    kterm -ls &
  elif type rxvt &> /dev/null ; then
    XMODIFIERS=@im=$XIM rxvt -ls &
  elif type Eterm &> /dev/null ; then
    Eterm -l &
  elif type gnome-terminal &> /dev/null ; then
    gnome-terminal --login &
  elif type xterm &> /dev/null ; then
    xterm -ls &
  fi
elif [ "$TERMINAL_EMULATOR" != "NONE" ] ; then
  $TERMINAL_EMULATOR &
fi

#=======================================================================
# ط
# (xlogo64 ϡxlib6g-dev ѥåäƤޤ)
#xsetroot -bitmap /usr/X11R6/include/X11/bitmaps/xlogo64 -fg RoyalBlue -bg RoyalBlue4 &
#xsetroot -solid SkyBlue
# ޥηˤ
#xsetroot -cursor /usr/include/X11/bitmaps/left_ptr /usr/include/X11/bitmaps/left_ptrmsk
EOF

if ($DOTFILECONTENTS2 eq "") {
	# ʾˤϤʤˤʤ
	print <<'EOF';
#
#=======================================================================
# åޥ͡㡢ɥޥ͡㡢ߥʥ륨ߥ졼
# 줫¹Ԥޤ ɤ줫ҤȤĤɬפǤ
# ¹Ԥ륦ɥޥ͡ $WINDOW_MANAGER ǻǽǤ
if [ -x "$WINDOW_MANAGER" ]; then
  realstartup=$WINDOW_MANAGER
elif [ -x /usr/bin/x-session-manager ]; then
  realstartup=x-session-manager
elif [ -x /usr/bin/x-window-manager ]; then
  realstartup=x-window-manager
elif [ -x /usr/bin/x-terminal-emulator ]; then
  realstartup=x-terminal-emulator
fi
exec $realstartup
EOF
} else {
	print <<'EOF';

#=======================================================================
# ɥޥ͡¹Ԥ꤬硢¹Ԥޤ
# $PASS_THROUGH 硢ɥޥ͡ϥХå饦ɤ
# ưʹߤƤ¹Ԥޤʤϻꥦɥޥ͡㤬
# ȤޤǤäȼ¹Ԥ졢ʹߤƤϼ¹Ԥޤ
if type "$WINDOW_MANAGER" >& /dev/null ; then
  if [ -z "$PASS_THROUGH" ]; then
    exec $WINDOW_MANAGER
  else
    $WINDOW_MANAGER &
  fi
fi
#=======================================================================
# $WINDOW_MANAGER λ꤬ʤȤޤϡ$WINDOW_MANAGER λ꤬
# ä $PASS_THROUGH λ⤢Ȥϡ³Ƥ³
# ¹Ԥޤ⤷åޥ͡䥦ɥޥ͡ʤɤ
# ¹Ԥ륳ޥɤʤ~/.xsession ˽λƤޤ硢
# 󤷤Ƥ⤹˥ȤƤޤʤɤԶ礬ޤΤ
# դƤ
EOF
}
